==> windmill_api-1.52.0.tar.gz: windmill_api-1.52.0/windmill_api/models/list_users_response_200_item_usage.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ListUsersResponse200ItemUsage")


@attr.s(auto_attribs=True)
class ListUsersResponse200ItemUsage:
    """
    Attributes:
        duration_ms (Union[Unset, int]):
        jobs (Union[Unset, int]):
        flows (Union[Unset, int]):
    """

    duration_ms: Union[Unset, int] = UNSET
    jobs: Union[Unset, int] = UNSET
    flows: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        duration_ms = self.duration_ms
        jobs = self.jobs
        flows = self.flows

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if duration_ms is not UNSET:
            field_dict["duration_ms"] = duration_ms
        if jobs is not UNSET:
            field_dict["jobs"] = jobs
        if flows is not UNSET:
            field_dict["flows"] = flows

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        duration_ms = d.pop("duration_ms", UNSET)

        jobs = d.pop("jobs", UNSET)

        flows = d.pop("flows", UNSET)

        list_users_response_200_item_usage = cls(
            duration_ms=duration_ms,
            jobs=jobs,
            flows=flows,
        )

        list_users_response_200_item_usage.additional_properties = d
        return list_users_response_200_item_usage

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.136.0.tar.gz: windmill_api-1.136.0/windmill_api/models/list_users_response_200_item_usage.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ListUsersResponse200ItemUsage")


@attr.s(auto_attribs=True)
class ListUsersResponse200ItemUsage:
    """
    Attributes:
        executions (Union[Unset, float]):
    """

    executions: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        executions = self.executions

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if executions is not UNSET:
            field_dict["executions"] = executions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        executions = d.pop("executions", UNSET)

        list_users_response_200_item_usage = cls(
            executions=executions,
        )

        list_users_response_200_item_usage.additional_properties = d
        return list_users_response_200_item_usage

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
